@@ -50,7 +50,7 @@ def __check_alias__(
 		os.system(f"chmod +x {path}")
 		os.system(f"chown {USER}:{GROUP} {path}")
 		try:
-			Files.File(path=f"{path}", data=file).save()
+			File(path=f"{path}", data=file).save()
 		except:
 			print(f"Unable to create alias $ {alias}.")
 			return None
