@@ -143,7 +143,7 @@ class R3sponse(object):
 			formats = formats.split(",")
 			param_format = Formats.get(parameter, serialize=True)
 			if param_format not in formats:
-				return self.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Files.Array(path=False, array=formats).string(joiner=', ')}.")
+				return self.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Array(path=False, array=formats).string(joiner=', ')}.")
 		return self.success(f"Succesfully checked parameter [{name}].")
 	def check_parameters(self, parameters={"parameter":None}, empty_value=None):
 		response = self.default_response()
@@ -194,7 +194,7 @@ class R3sponse(object):
 			else:
 				raise TypeError(e)
 		if comparison:
-			#print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
+			#print(f"{Date().seconds_timestamp} - {color.fill(msg)}")
 			if json:
 				if response != {}:
 					print(response.json())
@@ -238,7 +238,7 @@ class R3sponse(object):
 		response = self.default_response()
 		try:
 			with open(self.log_file, "a") as file:
-				file.write(f'{Formats.Date().seconds_timestamp} - {message}\n')
+				file.write(f'{Date().seconds_timestamp} - {message}\n')
 			response["success"] = True
 			response["message"] = "Succesfully logged the message."
 		except:
@@ -246,7 +246,7 @@ class R3sponse(object):
 			return response
 		
 		# check file size.
-		size = Formats.FilePath(self.log_file).size(mode="mb", type="integer")
+		size = FilePath(self.log_file).size(mode="mb", type="integer")
 		if int(size.replace(" MB", "")) >= 100: self.reset_logs()
 
 		# return response.
@@ -331,7 +331,7 @@ class ResponseObject(object):
 					try:
 						self.assign(ast.literal_eval(json))
 					except:
-						self.assign(pypi_json.loads(Formats.String(json).slice_dict()))
+						self.assign(pypi_json.loads(String(json).slice_dict()))
 			elif isinstance(json, dict):
 				self.assign(json)
 			elif json != None:
@@ -342,16 +342,16 @@ class ResponseObject(object):
 		# clean message & error.
 		try:
 			if self.message != None:
-				self.message = Formats.String(self.message).capitalized_word()
+				self.message = String(self.message).capitalized_word()
 			if self.error != None:
-				self.error = Formats.String(self.error).capitalized_word()
+				self.error = String(self.error).capitalized_word()
 			while True:
 				if self.message != None and len(self.message) >= 1 and self.message[len(self.message)-1] in [" ", ".", ","]:
 					self.message = self.message[:-1]
 				elif self.error != None and len(self.error) >= 1 and self.error[len(self.error)-1] in [" ", ".", ","]:
 					self.error = self.error[:-1]
 				elif self.error != None and len(self.error) >= len("Error: ") and self.error[:len("Error: ")] in ["Error: "]:
-					self.error = Formats.String(self.error[len("Error: "):]).capitalized_word()
+					self.error = String(self.error[len("Error: "):]).capitalized_word()
 				else: break
 			
 			# add dot.
@@ -409,7 +409,7 @@ class ResponseObject(object):
 		keys,
 	):
 		defaults = {}
-		if isinstance(keys, (dict, Files.Dictionary)):
+		if isinstance(keys, (dict, Dictionary)):
 			if isinstance(keys, dict):
 				defaults = dict(keys)
 				keys = list(keys.keys())
@@ -479,7 +479,7 @@ class ResponseObject(object):
 		if dictionary == None: dictionary = self.dict()
 		new = {}
 		if alphabetical or ascending:
-			_sorted_ = Files.Array(path=False, array=list(dictionary.keys())).sort(alphabetical=alphabetical, ascending=ascending, reversed=reversed)
+			_sorted_ = Array(path=False, array=list(dictionary.keys())).sort(alphabetical=alphabetical, ascending=ascending, reversed=reversed)
 		else: raise ValueError("Unknown behaviour, alphabetical=False.")
 		for key in _sorted_:
 			new[key] = dictionary[key]
@@ -497,7 +497,7 @@ class ResponseObject(object):
 	# serialize dict.
 	def serialize(self, sorted=False, reversed=False, json=False, dictionary=None):
 		if dictionary == None: dictionary = self.dict()
-		if isinstance(dictionary, Files.Dictionary):
+		if isinstance(dictionary, Dictionary):
 			dictionary = dictionary.dictionary
 		if sorted:
 			items = self.items(reversed=reversed, dictionary=self.sort(alphabetical=True, dictionary=dictionary))
@@ -506,10 +506,10 @@ class ResponseObject(object):
 		dictionary = {}
 		for key, value in items:
 			value = Formats.denitialize(value)
-			if isinstance(value, (dict, Files.Dictionary)):
+			if isinstance(value, (dict, Dictionary)):
 				value = self.serialize(json=json, sorted=sorted, reversed=reversed, dictionary=value)
-			elif isinstance(value, (list, Files.Array)):
-				value = Files.Array(value).serialize(json=json, sorted=sorted, reversed=reversed)
+			elif isinstance(value, (list, Array)):
+				value = Array(value).serialize(json=json, sorted=sorted, reversed=reversed)
 			elif isinstance(value, object):
 				value = str(value)
 			elif isinstance(value, str) or isinstance(value, bool) or value == None:
